@@ -14,10 +14,7 @@
 # ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT
 # OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest
+import unittest
 
 import dns.rrset
 import dns.rdtypes.ANY.LOC
@@ -31,7 +28,7 @@ class RdtypeAnyLocTestCase(unittest.TestCase):
         r2 = dns.rrset.from_text('FOO', 600, 'in', 'loc',
                                  '49 11 42.400 N 16 36 29.600 E 227.64m '
                                  '1.00m 10000.00m 10.00m')
-        self.failUnless(r1 == r2, '"%s" != "%s"' % (r1, r2))
+        self.failUnless(r1 == r2, '"{}" != "{}"'.format(r1, r2))
 
     def testEqual2(self):
         '''Test default values for size, horizontal and vertical precision.'''
@@ -42,7 +39,7 @@ class RdtypeAnyLocTestCase(unittest.TestCase):
                                      (16, 36, 29, 600, 1),
                                      22764.0, # centimeters
                                      100.0, 1000000.00, 1000.0)  # centimeters
-        self.failUnless(r1 == r2, '"%s" != "%s"' % (r1, r2))
+        self.failUnless(r1 == r2, '"{}" != "{}"'.format(r1, r2))
 
     def testEqual3(self):
         '''Test size, horizontal and vertical precision parsers: 100 cm == 1 m.
@@ -54,7 +51,7 @@ class RdtypeAnyLocTestCase(unittest.TestCase):
         r2 = dns.rrset.from_text('FOO', 600, 'in', 'loc',
                                  '49 11 42.400 N 16 36 29.600 E 227.64m '
                                  '2.00m 10.00m 2.00m')[0]
-        self.failUnless(r1 == r2, '"%s" != "%s"' % (r1, r2))
+        self.failUnless(r1 == r2, '"{}" != "{}"'.format(r1, r2))
 
     def testEqual4(self):
         '''Test size, horizontal and vertical precision parsers without unit.
@@ -67,7 +64,7 @@ class RdtypeAnyLocTestCase(unittest.TestCase):
         r2 = dns.rrset.from_text('FOO', 600, 'in', 'loc',
                                  '49 11 42.400 N 16 36 29.600 E 227.64 '
                                  '2 10 2')[0] # meters without explicit unit
-        self.failUnless(r1 == r2, '"%s" != "%s"' % (r1, r2))
+        self.failUnless(r1 == r2, '"{}" != "{}"'.format(r1, r2))
 
 if __name__ == '__main__':
     unittest.main()
